vcov.larf: Local Average Response Functions
Description
Methods to display the variance covariance matrix of the estimated parameters for the regression fitted by larf.Usage
## S3 method for class 'larf':
vcov(object, \dots)
Arguments
object
an object of class "larf" as fitted by larf.